@@ -70,6 +70,8 @@ class TestRunnerPodman(unittest.TestCase):
             '-e', 'HOME=%(homedir)s' % dict(homedir=HOME_DIR),
             '-v', '%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(homedir=HOME_DIR),
             '-v', '%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=HOME_DIR),
+            '-v', '%(homedir)s/.docker/config.json:%(homedir)s/.docker/config.json:ro' % dict(homedir=HOME_DIR),
+            '-v', '/etc/docker:/etc/docker:ro',
             '-v', '%(workdir)s:%(workdir)s:rw,shared' % dict(workdir=WORKDIR),
             '-v', 'entrypoint.sh:/opt/skipper/skipper-entrypoint.sh:rw',
             '-v', '/var/run/docker.sock:/var/run/docker.sock:rw',
@@ -107,6 +109,8 @@ class TestRunnerPodman(unittest.TestCase):
             '-e', 'HOME=%(homedir)s' % dict(homedir=HOME_DIR),
             '-v', '%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(homedir=HOME_DIR),
             '-v', '%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=HOME_DIR),
+            '-v', '%(homedir)s/.docker/config.json:%(homedir)s/.docker/config.json:ro' % dict(homedir=HOME_DIR),
+            '-v', '/etc/docker:/etc/docker:ro',
             '-v', '%(workdir)s:%(workdir)s:rw,shared' % dict(workdir=WORKDIR),
             '-v', 'entrypoint.sh:/opt/skipper/skipper-entrypoint.sh:rw',
             '-v', '/var/run/docker.sock:/var/run/docker.sock:rw',
@@ -144,6 +148,8 @@ class TestRunnerPodman(unittest.TestCase):
             '-e', 'HOME=%(homedir)s' % dict(homedir=HOME_DIR),
             '-v', '%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(homedir=HOME_DIR),
             '-v', '%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=HOME_DIR),
+            '-v', '%(homedir)s/.docker/config.json:%(homedir)s/.docker/config.json:ro' % dict(homedir=HOME_DIR),
+            '-v', '/etc/docker:/etc/docker:ro',
             '-v', '%(workdir)s:%(workdir)s:rw,shared' % dict(workdir=WORKDIR),
             '-v', 'entrypoint.sh:/opt/skipper/skipper-entrypoint.sh:rw',
             '-v', '/var/run/docker.sock:/var/run/docker.sock:rw',
@@ -183,6 +189,8 @@ class TestRunnerPodman(unittest.TestCase):
             '-e', 'HOME=%(homedir)s' % dict(homedir=HOME_DIR),
             '-v', '%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(homedir=HOME_DIR),
             '-v', '%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=HOME_DIR),
+            '-v', '%(homedir)s/.docker/config.json:%(homedir)s/.docker/config.json:ro' % dict(homedir=HOME_DIR),
+            '-v', '/etc/docker:/etc/docker:ro',
             '-v', '%(workdir)s:%(workdir)s:rw,shared' % dict(workdir=WORKDIR),
             '-v', 'entrypoint.sh:/opt/skipper/skipper-entrypoint.sh:rw',
             '-v', '/var/run/docker.sock:/var/run/docker.sock:rw',
